@@ -2,11 +2,11 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Notas",
-    "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
     "Error" : "Error",
     "New note" : "Nota nueva",
-    "Settings" : "Configuraciones ",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
+    "Settings" : "Configuraciones ",
+    "No notes yet" : "Aún no hay notas",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
     "Today" : "Hoy",
@@ -18,8 +18,8 @@ OC.L10N.register(
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Details" : "Detalles",
-    "Preview" : "Previsualizar",
     "Edit" : "Editar",
+    "Preview" : "Previsualizar",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
     "Saving failed!" : "¡Falla al guardar!",
