@@ -34,11 +34,12 @@ OC.L10N.register(
     "Empty note" : "یادداشت خالی",
     "Write …" : "نوشتن …",
     "Details" : "جزئیات",
-    "Edit" : "ویرایش کردن",
+    "Edit" : "ویرایش",
     "Preview" : "پیش نمایش",
     "Exit full screen" : "خروج از تمام صفحه",
     "Full screen" : "تمام صفحه",
     "Save failed. Click to retry." : "ذخیره نشد. برای امتحان دوباره کلیک کنید",
+    "Error from Nextcloud server: {msg}" : "خطا از سرور نکست کلود : {msg}",
     "Set category" : "تنظیم مجموعه",
     "Category" : "دسته‌بندی",
     "Uncategorized" : "دستهبندی نشده",
@@ -59,7 +60,6 @@ OC.L10N.register(
     "Note not found." : "یادداشتی یافت نشد",
     "Note is locked." : "یادداشت قفل شده است",
     "Updating settings has failed." : "به روزرسانی تنظیمات انجام نشد.",
-    "Error from Nextcloud server: {msg}" : "خطا از سرور نکست کلود : {msg}",
     "Fetching notes has failed." : "ثبت نام یادداشت انجام نشد.",
     "Fetching note {id} has failed." : "یادداشت برداری {id} انجام نشد.",
     "Creating new note has failed." : "ایجاد یادداشت جدید انجام نشد.",
